@@ -43,7 +43,7 @@
 #include "totem-interface.h"
 
 #ifdef ENABLE_PYTHON
-#include "rb-python-module.h"
+#include "totem-python-module.h"
 #endif
 
 #include "totem-plugins-engine.h"
@@ -57,7 +57,7 @@
 typedef enum
 {
 	TOTEM_PLUGIN_LOADER_C,
-	TOTEM_PLUGIN_LOADER_PY,
+	TOTEM_PLUGIN_LOADER_PY
 } TotemPluginLang;
 
 struct _TotemPluginInfo
@@ -159,12 +159,10 @@ totem_plugins_engine_load (const gchar *file)
 				     NULL);
 	if (str && strcmp(str, "python") == 0) {
 		info->lang = TOTEM_PLUGIN_LOADER_PY;
-#if 0
 #ifndef ENABLE_PYTHON
-		rb_debug ("Cannot load python extension '%s', Rhythmbox was not "
-					"compiled with python support", file);
+		g_debug ("Cannot load Python extension '%s', Totem was not "
+					"compiled with Python support", file);
 		goto error;
-#endif
 #endif
 	} else {
 		info->lang = TOTEM_PLUGIN_LOADER_C;
@@ -288,6 +286,7 @@ totem_plugins_engine_load_file (const char *plugin_file)
 
 	key_name = g_strdup_printf (GCONF_PREFIX_PLUGIN, info->location);
 	gconf_client_add_dir (client, key_name, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+	g_free (key_name);
 
 	key_name = g_strdup_printf (GCONF_PLUGIN_ACTIVE, info->location);
 	info->active_notification_id = gconf_client_notify_add (client,
@@ -364,7 +363,7 @@ totem_plugins_engine_init (TotemObject *totem)
 
 	if (!g_module_supported ())
 	{
-		g_warning ("rb is not able to initialize the plugins engine.");
+		g_warning ("Totem is not able to initialize the plugins engine.");
 		return FALSE;
 	}
 	totem_plugins = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, (GDestroyNotify)totem_plugin_info_free);
@@ -385,7 +384,7 @@ void
 totem_plugins_engine_garbage_collect (void)
 {
 #ifdef ENABLE_PYTHON
-	rb_python_garbage_collect ();
+	totem_python_garbage_collect ();
 #endif
 }
 
@@ -442,7 +441,7 @@ totem_plugins_engine_shutdown (void)
 	client = NULL;
 
 #ifdef ENABLE_PYTHON
-	rb_python_shutdown ();
+	totem_python_shutdown ();
 #endif
 }
 
@@ -502,12 +501,10 @@ load_plugin_module (TotemPluginInfo *info)
 			g_free (path);
 			break;
 		case TOTEM_PLUGIN_LOADER_PY:
-#if 0
 #ifdef ENABLE_PYTHON
-			info->module = G_TYPE_MODULE (rb_python_module_new (info->file, info->location));
+			info->module = G_TYPE_MODULE (totem_python_module_new (info->file, info->location));
 #else
-			rb_debug ("cannot load plugin %s, python plugin support is disabled", info->location);
-#endif
+			g_debug ("Cannot load plugin %s, Python plugin support is disabled", info->location);
 #endif
 			break;
 	}
@@ -527,7 +524,7 @@ load_plugin_module (TotemPluginInfo *info)
 			break;
 		case TOTEM_PLUGIN_LOADER_PY:
 #ifdef ENABLE_PYTHON
-			info->plugin = TOTEM_PLUGIN (rb_python_module_new_object (TOTEM_PYTHON_MODULE (info->module)));
+			info->plugin = TOTEM_PLUGIN (totem_python_module_new_object (TOTEM_PYTHON_MODULE (info->module)));
 #endif
 			break;
 	}
